@@ -22,7 +22,6 @@ __license__ = "Apache 2.0"
 
 
 import logging
-import sys
 
 from rcsb.db.sql.SqlGen import SqlGenCondition, SqlGenQuery
 
@@ -68,8 +67,10 @@ class QueryDirectives(object):
 
       Conditions for multiple values (ordered):
 
-       VALUE_LIST_CONDITION:<ordinal>:LOP:<logical conjunction (pre)>:ITEM:<tableId.columnId>:COP:<comparsion operator>:VALUE_LOP:<logical conjunction>:VALUE_LIST:<value>
-       VALUE_LIST_CONDITION:<ordinal>:LOP:<logical conjunction (pre)>:ITEM:<tableId.columnId>:COP:<comparsion operator>:VALUE_LOP:<logical conjunction>:VALUE_LIST:DOM_REF:<dom_form_id_name>
+       VALUE_LIST_CONDITION:<ordinal>:LOP:<logical conjunction (pre)>:ITEM:<tableId.columnId>:COP:<comparsion operator>:
+               VALUE_LOP:<logical conjunction>:VALUE_LIST:<value>
+       VALUE_LIST_CONDITION:<ordinal>:LOP:<logical conjunction (pre)>:ITEM:<tableId.columnId>:COP:<comparsion operator>:
+               VALUE_LOP:<logical conjunction>:VALUE_LIST:DOM_REF:<dom_form_id_name>
 
        < comparison operator > in ['EQ', 'NE', 'GE', 'GT', 'LT', 'LE', 'LIKE', 'NOT LIKE']
 
@@ -133,20 +134,21 @@ class QueryDirectives(object):
              schemaDefObj =  is instance of class derived from SchemaDefBase().
 
         """
-        self.__sd = schemaDefObj
+        self.__sD = schemaDefObj
         self.__verbose = verbose
         self.__debug = True
         #
         self.__selectTupList = []
         self.__orgSelectCount = 0
 
-    def build(self, queryDirL=[], domD={}, appendValueConditonsToSelect=False, queryDirSeparator=':', domRefSeparator='|'):
-        ''' Build SQL instructure from the input list of query directives and dictionary or dom references.
+    def build(self, queryDirL=None, domD=None, appendValueConditonsToSelect=False, queryDirSeparator=":", domRefSeparator="|"):
+        """ Build SQL instructure from the input list of query directives and dictionary or dom references.
 
-        '''
+        """
+        queryDirL = queryDirL if queryDirL else []
+        domD = domD if domD else {}
         if self.__verbose:
-            logger.debug("\n+%s.%s() dom dictionary length domD %d\n" %
-                         (self.__class__.__name__, sys._getframe().f_code.co_name, len(domD)))
+            logger.debug("dom dictionary length domD %d\n", len(domD))
         tL = []
         qL = []
         self.__selectTupList = []
@@ -161,9 +163,9 @@ class QueryDirectives(object):
         qL = self.__queryDirSub(inpQueryDirList=tL, domD=domD, domRefSeparator=domRefSeparator)
 
         if self.__debug:
-            logger.debug("+%s.%s() length qL %d\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, len(qL)))
-            for q in qL:
-                logger.debug("+%s.%s() qL %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, q))
+            logger.debug("length qL %d\n", len(qL))
+            for qV in qL:
+                logger.debug("qL %r\n", qV)
         # Now parse the token list --
         #
         selectD, orderD, conditionD, self.__orgSelectCount = self.__parseTokenList(qL, appendValueConditonsToSelect)
@@ -176,8 +178,8 @@ class QueryDirectives(object):
         return self.__selectTupList, self.__orgSelectCount
 
     def __getTokenD(self, tL, index, nPairs):
-        '''  Return a dictionary of token and value pairs in the input list starting at tL[index].
-        '''
+        """  Return a dictionary of token and value pairs in the input list starting at tL[index].
+        """
         tD = {}
         try:
             i1 = index
@@ -186,13 +188,14 @@ class QueryDirectives(object):
                 tD[tL[i]] = tL[i + 1]
         except Exception as e:
             if self.__verbose:
-                logger.error("\n+%s.%s() fails with index %d nPairs %d tL %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, index, nPairs, tL))
-                logger.exception("Failing with %s" % str(e))
+                logger.error("fails with index %d nPairs %d tL %r", index, nPairs, tL)
+                logger.exception("Failing with %s", str(e))
 
         return tD
 
         #
         #
+
     def __parseTokenList(self, qdL, appendValueConditonsToSelect=False):
         """
             Parse input list of tokens and return dictionaries of instructions (selections, conditions, sorting order)
@@ -211,97 +214,97 @@ class QueryDirectives(object):
             while i < len(qdL):
                 # Get selections  -
                 #
-                if qdL[i] in ['SELECT_ITEM']:
+                if qdL[i] in ["SELECT_ITEM"]:
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 1)
-                    if (('ITEM' in tD) and (tD['ITEM'] is not None)):
-                        tdotc = str(tD['ITEM']).split('.')
+                    if ("ITEM" in tD) and (tD["ITEM"] is not None):
+                        tdotc = str(tD["ITEM"]).split(".")
                         # (tableId, attributeId)  apply the upper case convention used in schema map
                         selectD[ordinal] = (tdotc[0].upper(), tdotc[1].upper())
                     else:
                         if self.__verbose:
-                            logger.debug("\n+%s.%s() selection incomplete at i = %d\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, i))
+                            logger.debug("selection incomplete at i = %d\n", i)
                             for k, v in tD.items():
-                                logger.debug(" --- tD --  %r %r\n" % (k, v))
+                                logger.debug(" --- tD --  %r %r\n", k, v)
                         # raise ValueError("Selection definition incomplete")
                     i += 4
                     continue
-                elif qdL[i] in ['VALUE_CONDITION']:
+                elif qdL[i] in ["VALUE_CONDITION"]:
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 4)
-                    if (('VALUE' in tD) and (tD['VALUE'] is not None)):
-                        if 'LOP' in tD and 'ITEM' in tD and 'COP' in tD:
-                            tdotc = str(tD['ITEM']).split('.')
+                    if ("VALUE" in tD) and (tD["VALUE"] is not None):
+                        if "LOP" in tD and "ITEM" in tD and "COP" in tD:
+                            tdotc = str(tD["ITEM"]).split(".")
                             tableId = tdotc[0].upper()
                             attributeId = tdotc[1].upper()
                             tObj = self.__sD.getSchemaObject(tableId)
                             aType = tObj.getAttributeType(attributeId)
-                            cop = str(tD['COP']).upper()
-                            conditionD[ordinal] = {'cType': 'value', 'lOp': tD['LOP'], 'cObj': ((tableId, attributeId), cop, (tD['VALUE'], aType))}
+                            cop = str(tD["COP"]).upper()
+                            conditionD[ordinal] = {"cType": "value", "lOp": tD["LOP"], "cObj": ((tableId, attributeId), cop, (tD["VALUE"], aType))}
                         else:
                             raise ValueError("Value condition incomplete")
                     else:
                         pass
                     i += 10
                     continue
-                elif qdL[i] in ['VALUE_LIST_CONDITION']:
+                elif qdL[i] in ["VALUE_LIST_CONDITION"]:
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 5)
-                    if (('VALUE_LIST' in tD) and (tD['VALUE_LIST'] is not None)):
-                        if 'LOP' in tD and 'ITEM' in tD and 'COP' in tD and 'VALUE_LOP' in tD:
-                            tdotc = str(tD['ITEM']).split('.')
+                    if ("VALUE_LIST" in tD) and (tD["VALUE_LIST"] is not None):
+                        if "LOP" in tD and "ITEM" in tD and "COP" in tD and "VALUE_LOP" in tD:
+                            tdotc = str(tD["ITEM"]).split(".")
                             tableId = tdotc[0].upper()
                             attributeId = tdotc[1].upper()
                             tObj = self.__sD.getSchemaObject(tableId)
                             aType = tObj.getAttributeType(attributeId)
-                            cop = str(tD['COP']).upper()
-                            vLop = str(tD['VALUE_LOP']).upper()
-                            if isinstance(tD['VALUE_LIST'], list):
-                                vL = tD['VALUE_LIST']
+                            cop = str(tD["COP"]).upper()
+                            vLop = str(tD["VALUE_LOP"]).upper()
+                            if isinstance(tD["VALUE_LIST"], list):
+                                vL = tD["VALUE_LIST"]
                             else:
-                                vL = [tD['VALUE_LIST']]
-                            conditionD[ordinal] = {'cType': 'value_list', 'lOp': tD['LOP'], 'cObj': ((tableId, attributeId), cop, vLop, (vL, aType))}
+                                vL = [tD["VALUE_LIST"]]
+                            conditionD[ordinal] = {"cType": "value_list", "lOp": tD["LOP"], "cObj": ((tableId, attributeId), cop, vLop, (vL, aType))}
                         else:
                             raise ValueError("Value list condition incomplete")
                     else:
                         pass
                     i += 12
                     continue
-                elif qdL[i] in ['JOIN_CONDITION']:
+                elif qdL[i] in ["JOIN_CONDITION"]:
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 4)
-                    if 'LOP' in tD and 'L_ITEM' in tD and 'COP' in tD and 'R_ITEM' in tD:
-                        ltdotc = str(tD['L_ITEM']).split('.')
+                    if "LOP" in tD and "L_ITEM" in tD and "COP" in tD and "R_ITEM" in tD:
+                        ltdotc = str(tD["L_ITEM"]).split(".")
                         ltableId = ltdotc[0].upper()
                         lattributeId = ltdotc[1].upper()
-                        rtdotc = str(tD['R_ITEM']).split('.')
+                        rtdotc = str(tD["R_ITEM"]).split(".")
                         rtableId = rtdotc[0].upper()
                         rattributeId = rtdotc[1].upper()
-                        cop = str(tD['COP']).upper()
-                        conditionD[ordinal] = {'cType': 'join', 'lOp': tD['LOP'], 'cObj': ((ltableId, lattributeId), cop, (rtableId, rattributeId))}
+                        cop = str(tD["COP"]).upper()
+                        conditionD[ordinal] = {"cType": "join", "lOp": tD["LOP"], "cObj": ((ltableId, lattributeId), cop, (rtableId, rattributeId))}
                     else:
                         raise ValueError("Join condition incomplete")
                     i += 10
                     continue
-                elif qdL[i] in ['CONDITION_LIST']:
+                elif qdL[i] in ["CONDITION_LIST"]:
                     # example: CONDITION_LIST:1:KEY:mr:LOP:OR:ITEM:pdbx_webselect.solution:COP:LIKE:VALUE:%MR%
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 5)
-                    if (('VALUE' in tD) and (tD['VALUE'] is not None)):
-                        if 'LOP' in tD and 'ITEM' in tD and 'COP' in tD and 'KEY' in tD:
-                            tdotc = str(tD['ITEM']).split('.')
+                    if ("VALUE" in tD) and (tD["VALUE"] is not None):
+                        if "LOP" in tD and "ITEM" in tD and "COP" in tD and "KEY" in tD:
+                            tdotc = str(tD["ITEM"]).split(".")
                             tableId = tdotc[0].upper()
                             attributeId = tdotc[1].upper()
                             tObj = self.__sD.getSchemaObject(tableId)
                             aType = tObj.getAttributeType(attributeId)
-                            cop = str(tD['COP']).upper()
-                            ky = str(tD['KEY'])
+                            cop = str(tD["COP"]).upper()
+                            ky = str(tD["KEY"])
                             # ('PDB_ENTRY_TMP', 'PDB_ID'), 'LIKE', ('x-ray', 'char'), 'AND')
                             if ordinal not in condListD:
                                 condListD[ordinal] = {}
                             if ky not in condListD[ordinal]:
                                 condListD[ordinal][ky] = []
-                            condListD[ordinal][ky].append((tD['LOP'], (tableId, attributeId), cop, (tD['VALUE'], aType)))
+                            condListD[ordinal][ky].append((tD["LOP"], (tableId, attributeId), cop, (tD["VALUE"], aType)))
                         else:
                             raise ValueError("Value condition incomplete")
                     else:
@@ -309,38 +312,38 @@ class QueryDirectives(object):
 
                     i += 12
                     continue
-                elif qdL[i] in ['VALUE_KEYED_CONDITION']:
+                elif qdL[i] in ["VALUE_KEYED_CONDITION"]:
                     # example: "VALUE_KEYED_CONDITION:15:LOP:AND:CONDITION_LIST_ID:1:VALUE:DOM_REF:solution"
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 3)
-                    if (('VALUE' in tD) and (tD['VALUE'] is not None)):
-                        if 'LOP' in tD and 'CONDITION_LIST_ID' in tD:
-                            keyCondD[ordinal] = (int(str(tD['CONDITION_LIST_ID'])), tD['VALUE'], tD['LOP'])
+                    if ("VALUE" in tD) and (tD["VALUE"] is not None):
+                        if "LOP" in tD and "CONDITION_LIST_ID" in tD:
+                            keyCondD[ordinal] = (int(str(tD["CONDITION_LIST_ID"])), tD["VALUE"], tD["LOP"])
                         else:
                             raise ValueError("Value key condition incomplete")
                     else:
                         pass
                     i += 8
                     continue
-                elif qdL[i] in ['ORDER_ITEM']:
+                elif qdL[i] in ["ORDER_ITEM"]:
                     ordinal = int(str(qdL[i + 1]))
                     tD = self.__getTokenD(qdL, i + 2, 2)
-                    if (('ITEM' in tD) and ('SORT_ORDER' in tD) and (tD['ITEM'] is not None)):
-                        tdotc = str(tD['ITEM']).split('.')
+                    if ("ITEM" in tD) and ("SORT_ORDER" in tD) and (tD["ITEM"] is not None):
+                        tdotc = str(tD["ITEM"]).split(".")
                         # (tableId, attributeId)  apply the upper case convention used in schema map
-                        if tD['SORT_ORDER'] in ['ASC', 'ASCENDING', 'INCREASING']:
-                            sf = 'ASC'
-                        elif tD['SORT_ORDER'] in ['DESC', 'DESCENDING', 'DECREASING']:
-                            sf = 'DESC'
+                        if tD["SORT_ORDER"] in ["ASC", "ASCENDING", "INCREASING"]:
+                            sf = "ASC"
+                        elif tD["SORT_ORDER"] in ["DESC", "DESCENDING", "DECREASING"]:
+                            sf = "DESC"
                         else:
-                            sf = 'ASC'
+                            sf = "ASC"
 
                         orderD[ordinal] = ((tdotc[0].upper(), tdotc[1].upper()), sf)
                     else:
                         if self.__verbose:
-                            logger.debug("\n+%s.%s() orderby incomplete at i = %d\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, i))
+                            logger.debug("orderby incomplete at i = %d", i)
                             for k, v in tD.items():
-                                logger.debug(" --- tD --  %r %r\n" % (k, v))
+                                logger.debug(" --- tD --  %r %r", k, v)
                         # raise ValueError("Order definition incomplete")
                     i += 6
                     continue
@@ -348,41 +351,41 @@ class QueryDirectives(object):
                     pass
         except Exception as e:
             if self.__verbose:
-                logger.error("\n+%s.%s() fails at i = %d\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, i))
+                logger.error("fails at i = %d", i)
                 for k, v in tD.items():
-                    logger.error(" --- tD --  %r %r\n" % (k, v))
-                logger.exception("Failing with %s" % str(e))
+                    logger.error(" --- tD --  %r %r\n", k, v)
+                logger.exception("Failing with %s", str(e))
 
         #
         # Create condition groups by expanding key-value condition definition using the supporting condition list info in condListD ...
         #
         for ordinal, keyCond in keyCondD.items():
             condListId, keyValue, lOp = keyCond
-            conditionD[ordinal] = {'cType': 'group', 'lOp': lOp, 'cObj': []}
+            conditionD[ordinal] = {"cType": "group", "lOp": lOp, "cObj": []}
             if condListId in condListD:
-                logger.debug("++++condListId %r keyValue %r lOp %r\n" % (condListId, keyValue, lOp))
+                logger.debug("++++condListId %r keyValue %r lOp %r\n", condListId, keyValue, lOp)
                 if keyValue in condListD[condListId]:
                     for cond in condListD[condListId][keyValue]:
-                        logger.debug("+++++++condListId %r keyValue %r lOp %r cond %r\n" % (condListId, keyValue, lOp, cond))
+                        logger.debug("+++++++condListId %r keyValue %r lOp %r cond %r", condListId, keyValue, lOp, cond)
                         # example : ('OR', ('PDBX_WEBSELECT', 'METHOD_TO_DETERMINE_STRUCT'), 'LIKE', ('MOLECULAR REPLACEMENT', 'char')
                         # using  condListD[ordinal][ky].append((tD['LOP'], (tableId, attributeId), cop, (tD['VALUE'], aType)))
-                        conditionD[ordinal]['cObj'].append(cond)
+                        conditionD[ordinal]["cObj"].append(cond)
         #
         if self.__verbose:
             for k, v in selectD.items():
-                logger.debug("\n+%s.%s() select %r  %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, k, v))
+                logger.debug("select %r  %r", k, v)
             for k, v in orderD.items():
-                logger.debug("\n+%s.%s() order  %r  %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, k, v))
+                logger.debug("order  %r  %r", k, v)
             #
             for k, v in keyCondD.items():
-                logger.debug("\n+%s.%s() keycondD  %r  %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, k, v))
+                logger.debug("keycondD  %r  %r", k, v)
             for k1, vD in condListD.items():
                 for k2, v in vD.items():
-                    logger.debug("\n+%s.%s() condListD %r  %r  %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, k1, k2, v))
+                    logger.debug("condListD %r  %r  %r", k1, k2, v)
             #
             for k1, vD in conditionD.items():
                 for k2, v in vD.items():
-                    logger.debug("\n+%s.%s() ordinal %3d type %r: %r\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, k1, k2, v))
+                    logger.debug("ordinal %3d type %r: %r", k1, k2, v)
 
         #
         orgSelectCount = len(selectD)
@@ -390,12 +393,12 @@ class QueryDirectives(object):
             vSelectL = []
             for k in sorted(conditionD.keys()):
                 tD = conditionD[k]
-                if tD['cType'] in ['value', 'value_list']:
-                    vSelectL.append(tD['cObj'][0])
-                elif tD['cType'] in ['group']:
-                    cL = tD['cObj']
-                    for c in cL:
-                        vSelectL.append(c[1])
+                if tD["cType"] in ["value", "value_list"]:
+                    vSelectL.append(tD["cObj"][0])
+                elif tD["cType"] in ["group"]:
+                    cL = tD["cObj"]
+                    for cV in cL:
+                        vSelectL.append(cV[1])
             nxtOrd = max(selectD.keys()) + 1
             for vSelect in vSelectL:
                 selectD[nxtOrd] = vSelect
@@ -406,7 +409,7 @@ class QueryDirectives(object):
 
     def __sqlGen(self, selectD, orderD, conditionD):
         #
-        sqlGen = SqlGenQuery(schemaDefObj=self.__sd, verbose=self.__verbose)
+        sqlGen = SqlGenQuery(schemaDefObj=self.__sD, verbose=self.__verbose)
 
         sTableIdList = []
         #        for sTup in sList:
@@ -416,20 +419,19 @@ class QueryDirectives(object):
             sTableIdList.append(sTup[0])
             self.__selectTupList.append(sTup)
 
-        sqlCondition = SqlGenCondition(schemaDefObj=self.__sd, verbose=self.__verbose)
-        if len(conditionD) > 0:
-
+        sqlCondition = SqlGenCondition(schemaDefObj=self.__sD, verbose=self.__verbose)
+        if conditionD:
             for k in sorted(conditionD.keys()):
                 cD = conditionD[k]
-                cObj = cD['cObj']
-                lOp = cD['lOp']
-                if cD['cType'] in ['value']:
+                cObj = cD["cObj"]
+                lOp = cD["lOp"]
+                if cD["cType"] in ["value"]:
                     sqlCondition.addValueCondition(lhsTuple=cObj[0], opCode=cObj[1], rhsTuple=cObj[2], preOp=lOp)
-                elif cD['cType'] in ['join']:
+                elif cD["cType"] in ["join"]:
                     sqlCondition.addJoinCondition(lhsTuple=cObj[0], opCode=cObj[1], rhsTuple=cObj[2], preOp=lOp)
-                elif cD['cType'] in ['group']:
-                    sqlCondition.addGroupValueConditionList(cD['cObj'], preOp=lOp)
-                elif cD['cType'] in ['value_list']:
+                elif cD["cType"] in ["group"]:
+                    sqlCondition.addGroupValueConditionList(cD["cObj"], preOp=lOp)
+                elif cD["cType"] in ["value_list"]:
                     # build cDefList = [(lPreOp,lhsTuple, opCode, rhsTuple), ...] from value_list -
                     # cObj  = ((tableId, attributeId), cop, vLop, (tD['VALUE_LIST'], aType))}
                     #
@@ -454,13 +456,13 @@ class QueryDirectives(object):
             sqlGen.addOrderByAttributeId(attributeTuple=oTup, sortFlag=sf)
         #
         sqlS = sqlGen.getSql()
-        if (self.__verbose):
-            logger.debug("\n+%s.%s() sql:\n%s\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, sqlS))
+        if self.__verbose:
+            logger.debug("sql:\n%s", sqlS)
         sqlGen.clear()
         #
         return sqlS
 
-    def __queryDirSub(self, inpQueryDirList, domD={}, domRefSeparator='|'):
+    def __queryDirSub(self, inpQueryDirList, domD=None, domRefSeparator="|"):
         """  Substitute DOM references into the input query directive list -
 
              Substitions:
@@ -471,44 +473,45 @@ class QueryDirectives(object):
                                     multiple correlated values as in a "select" (e.g. dom-ref -> myselect = "value1|value2")
 
         """
+        domD = domD if domD else {}
         qL = []
         try:
             i = 0
-            while (i < len(inpQueryDirList)):
-                t = inpQueryDirList[i]
-                if t.upper().startswith('DOM_REF_'):
-                    indx = int(str(t.upper()).split('_')[2])
-                    if inpQueryDirList[i + 1] in domD and domD[inpQueryDirList[i + 1]] is not None and len(domD[inpQueryDirList[i + 1]]) > 0:
-                        if (isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) > 1)):
+            while i < len(inpQueryDirList):
+                tV = inpQueryDirList[i]
+                if tV.upper().startswith("DOM_REF_"):
+                    indx = int(str(tV.upper()).split("_")[2])
+                    if inpQueryDirList[i + 1] in domD and domD[inpQueryDirList[i + 1]] is not None and domD[inpQueryDirList[i + 1]]:
+                        if isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) > 1):
                             tV = [str(tt).split(domRefSeparator)[indx] for tt in domD[inpQueryDirList[i + 1]]]
-                        elif (isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) == 1)):
+                        elif isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) == 1):
                             tV = str(domD[inpQueryDirList[i + 1]][0]).split(domRefSeparator)[indx]
                         else:
                             tV = str(domD[inpQueryDirList[i + 1]]).split(domRefSeparator)[indx]
                     else:
-                        tV = ''
-                    qL.append(tV if len(tV) > 0 else None)
+                        tV = ""
+                    qL.append(tV if tV else None)
                     i += 1
-                elif t.upper() in ['DOM_REF']:
-                    if ((inpQueryDirList[i + 1] in domD) and (domD[inpQueryDirList[i + 1]] is not None) and (len(domD[inpQueryDirList[i + 1]]) > 0)):
-                        if (isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) > 1)):
+                elif tV.upper() in ["DOM_REF"]:
+                    if (inpQueryDirList[i + 1] in domD) and (domD[inpQueryDirList[i + 1]] is not None) and domD[inpQueryDirList[i + 1]]:
+                        if isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) > 1):
                             tV = domD[inpQueryDirList[i + 1]]
-                        elif (isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) == 1)):
+                        elif isinstance(domD[inpQueryDirList[i + 1]], list) and (len(domD[inpQueryDirList[i + 1]]) == 1):
                             tV = domD[inpQueryDirList[i + 1]][0]
                         else:
                             tV = domD[inpQueryDirList[i + 1]]
                     else:
-                        tV = ''
-                    qL.append(tV if len(tV) > 0 else None)
+                        tV = ""
+                    qL.append(tV if tV else None)
                     i += 1
                 else:
-                    qL.append(t)
+                    qL.append(tV)
                 i += 1
         except Exception as e:
             if self.__verbose:
-                logger.error("\n+%s.%s() fails at i = %d\n" % (self.__class__.__name__, sys._getframe().f_code.co_name, i))
+                logger.error("fails at i = %d", i)
                 for ii, qd in enumerate(inpQueryDirList):
-                    logger.error(" --- qd %4d  %r\n" % (ii, qd))
-                logger.exception("Failing with %s" % str(e))
+                    logger.error(" --- qd %4d  %r\n", ii, qd)
+                logger.exception("Failing with %s", str(e))
 
         return qL
